from setuptools import setup, find_packages

setup(
    name='smathbyviraj',
    version='0.3.0',
    author='Viraj',
    description='Simple math utilities by Viraj',
    packages=find_packages(),
    include_package_data=True,
    python_requires='>=3.6',
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
)